.. image:: https://travis-ci.org/IMIO/imio.helpers.svg?branch=master
   :target: https://travis-ci.org/IMIO/imio.helpers

.. image:: https://coveralls.io/repos/IMIO/imio.helpers/badge.png?branch=master
   :target: https://coveralls.io/r/IMIO/imio.helpers?branch=master


====================
imio.helpers
====================

Various helper methods for development.
